@@ -23,7 +23,7 @@
 //! - Because UDP is a "connectionless" protocol, it offers no guarantee of "conversation" between traditional client and server roles. All the UDP transport layer gives you is a method to listen for messages thrown at you, and to throw messages at someone. Owing to this, CoAP machines are expected to perform both client and server roles (or more accurately, _sender_ and _receiver_ roles)
 //! - While _classes_ of status codes are the same (Success 2xx -> 2.xx, Client error 4xx -> 4.xx, Server error 5xx -> 5.xx), the semantics of the individual response codes differ.
 
-#![doc(html_root_url = "https://docs.rs/kwap/0.1.5")]
+#![doc(html_root_url = "https://docs.rs/kwap/0.1.6")]
 #![cfg_attr(all(not(test), feature = "no_std"), no_std)]
 #![cfg_attr(not(test),
             deny(missing_debug_implementations,
@@ -134,6 +134,7 @@ use kwap_msg::{Opt, OptDelta, OptNumber};
 
 #[cfg(test)]
 pub(crate) mod test {
+  use kwap_msg::OptValue;
   use no_std_net::{SocketAddr, ToSocketAddrs};
   use socket::*;
 
@@ -173,4 +174,63 @@ pub(crate) mod test {
       Ok(())
     }
   }
+
+  #[test]
+  fn add_option_updates_when_exist() {
+    let mut opts = vec![(OptNumber(0),
+                         Opt::<Vec<u8>> { delta: OptDelta(0),
+                                          value: OptValue(vec![]) })];
+
+    let out = add_option(&mut opts, 0, vec![1]);
+
+    assert!(out.is_none());
+    assert_eq!(opts.len(), 1);
+    assert_eq!(opts[0].1.value.0, vec![1]);
+  }
+
+  #[test]
+  fn add_option_adds_when_not_exist() {
+    let mut opts = Vec::<(_, Opt<Vec<u8>>)>::new();
+
+    let out = add_option(&mut opts, 0, vec![1]);
+
+    assert!(out.is_none());
+    assert_eq!(opts.len(), 1);
+    assert_eq!(opts[0].1.value.0, vec![1]);
+  }
+
+  #[test]
+  fn normalize_opts_echoes_when_empty() {
+    let opts = Vec::<(OptNumber, Opt<Vec<u8>>)>::new();
+    let out = normalize_opts::<_, Vec<Opt<Vec<u8>>>, _>(opts);
+    assert!(out.is_empty())
+  }
+
+  #[test]
+  fn normalize_opts_works() {
+    let opts: Vec<(OptNumber, Opt<Vec<u8>>)> = vec![(OptNumber(32), Default::default()),
+                                                    (OptNumber(1), Default::default()),
+                                                    (OptNumber(3), Default::default()),];
+
+    let expect: Vec<Opt<Vec<u8>>> = vec![Opt { delta: OptDelta(1),
+                                               ..Default::default() },
+                                         Opt { delta: OptDelta(2),
+                                               ..Default::default() },
+                                         Opt { delta: OptDelta(29),
+                                               ..Default::default() },];
+
+    let actual = normalize_opts::<_, Vec<Opt<Vec<u8>>>, _>(opts);
+
+    assert_eq!(actual, expect)
+  }
+
+  #[test]
+  fn add_option_rets_some_when_full() {
+    let mut opts =
+      tinyvec::ArrayVec::<[(OptNumber, Opt<Vec<u8>>); 1]>::from([(OptNumber(1), Opt::<Vec<u8>>::default())]);
+
+    let out = add_option(&mut opts, 0, vec![1]);
+
+    assert_eq!(out, Some((0, vec![1])));
+  }
 }
